@@ -2,7 +2,7 @@ from datetime import datetime
 
 from django.db import models
 
-from .utils import AUTH_USER_MODEL
+from .compat import AUTH_USER_MODEL
 from .managers import BasisModelManager
 
 
@@ -10,10 +10,12 @@ class BasisModel(models.Model):
     deleted = models.BooleanField(default=False, editable=False)
 
     created_at = models.DateTimeField(default=datetime.now, editable=False, auto_now_add=True)
-    created_by = models.ForeignKey(AUTH_USER_MODEL, null=True, default=None, editable=False, related_name="%(class)s_created")
+    created_by = models.ForeignKey(AUTH_USER_MODEL, null=True, default=None, editable=False,
+                                   related_name="%(class)s_created")
 
     updated_at = models.DateTimeField(default=datetime.now, editable=False, auto_now=True)
-    updated_by = models.ForeignKey(AUTH_USER_MODEL, null=True, default=None, editable=False, related_name="%(class)s_updated")
+    updated_by = models.ForeignKey(AUTH_USER_MODEL, null=True, default=None, editable=False,
+                                   related_name="%(class)s_updated")
 
     objects = BasisModelManager()
     all_objects = models.Manager()
